@@ -1,6 +1,7 @@
 
 from django import forms
 from django.core.validators import EMPTY_VALUES
+from django.forms.models import ModelChoiceField
 
 from forms_ext.validators import EachSequenceItemLengthValidator
 
@@ -17,7 +18,8 @@ class ForeignKeyChoiceField(forms.ModelChoiceField):
     def to_python(self, value):
         if value in EMPTY_VALUES:
             return None
-        return self.model_class(pk=value)
+        field_name = self.to_field_name or 'pk'
+        return self.model_class.objects.get(**{field_name:value})
 
 class CommaSeparatedField(forms.CharField):
     description = "Comma-separated strings"
@@ -37,3 +39,11 @@ class CommaSeparatedField(forms.CharField):
         if isinstance(value, basestring):
             return value
         return value and ','.join(v for v in value if v)
+
+class QuerysetChoiceField(ModelChoiceField):
+
+    def to_python(self, value):
+        try:
+            return int(value)
+        except (ValueError, TypeError):
+            return None
